#ifndef INCLUDED_VERSION_H
#define INCLUDED_VERSION_H

#define LIBCHARDET_MAJOR_VER 1
#define LIBCHARDET_MINOR_VER 0
#define LIBCHARDET_PATCH_VER 6

#define LIBCHARDET_VERSION "1.0.6"
#define LIBCHARDET_UVERSION "001000006"
#define LIBCHARDET_LVERSION 0x01000006

#endif /* INCLUDED_VERSION_H */
